/*
 * This file is part of libbluray
 * Copyright (C) 2010  William Hahne
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see
 * <http://www.gnu.org/licenses/>.
 */

package org.havi.ui;

public class HScreenDimension {
    public HScreenDimension(float width, float height) {
        setSize(width, height);
    }

    public void setSize(float width, float height) {
        if (width < 0.0f)
            width = 0.0f;
        if (height < 0.0f)
            height = 0.0f;
        this.width = width;
        this.height = height;
    }

    public String toString() {
        return getClass().getName() + "[" + width + "x" + height + "]";
    }

    public float width;
    public float height;
}
